==> esp8266-0.3.0.crate: esp8266-0.3.0/src/slc/slc_tx_fifo_pop.rs <==
#[doc = "Register `SLC_TX_FIFO_POP` reader"]
pub struct R(crate::R<SLC_TX_FIFO_POP_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_TX_FIFO_POP_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<SLC_TX_FIFO_POP_SPEC>> for R {
    fn from(reader: crate::R<SLC_TX_FIFO_POP_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_TX_FIFO_POP` writer"]
pub struct W(crate::W<SLC_TX_FIFO_POP_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_TX_FIFO_POP_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<SLC_TX_FIFO_POP_SPEC>> for W {
    fn from(writer: crate::W<SLC_TX_FIFO_POP_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TXFIFO_POP` reader - "]
pub struct SLC_TXFIFO_POP_R(crate::FieldReader<bool, bool>);
impl SLC_TXFIFO_POP_R {
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXFIFO_POP_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXFIFO_POP_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXFIFO_POP` writer - "]
pub struct SLC_TXFIFO_POP_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXFIFO_POP_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
        self.w
    }
}
#[doc = "Field `SLC_TXFIFO_RDATA` reader - "]
pub struct SLC_TXFIFO_RDATA_R(crate::FieldReader<u16, u16>);
impl SLC_TXFIFO_RDATA_R {
    pub(crate) fn new(bits: u16) -> Self {
        SLC_TXFIFO_RDATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXFIFO_RDATA_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXFIFO_RDATA` writer - "]
pub struct SLC_TXFIFO_RDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXFIFO_RDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x07ff) | ((value as u32) & 0x07ff);
        self.w
    }
}
impl R {
    #[doc = "Bit 16"]
    #[inline(always)]
    pub fn slc_txfifo_pop(&self) -> SLC_TXFIFO_POP_R {
        SLC_TXFIFO_POP_R::new(((self.bits >> 16) & 0x01) != 0)
    }
    #[doc = "Bits 0:10"]
    #[inline(always)]
    pub fn slc_txfifo_rdata(&self) -> SLC_TXFIFO_RDATA_R {
        SLC_TXFIFO_RDATA_R::new((self.bits & 0x07ff) as u16)
    }
}
impl W {
    #[doc = "Bit 16"]
    #[inline(always)]
    pub fn slc_txfifo_pop(&mut self) -> SLC_TXFIFO_POP_W {
        SLC_TXFIFO_POP_W { w: self }
    }
    #[doc = "Bits 0:10"]
    #[inline(always)]
    pub fn slc_txfifo_rdata(&mut self) -> SLC_TXFIFO_RDATA_W {
        SLC_TXFIFO_RDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_TX_FIFO_POP\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_tx_fifo_pop](index.html) module"]
pub struct SLC_TX_FIFO_POP_SPEC;
impl crate::RegisterSpec for SLC_TX_FIFO_POP_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_tx_fifo_pop::R](R) reader structure"]
impl crate::Readable for SLC_TX_FIFO_POP_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_tx_fifo_pop::W](W) writer structure"]
impl crate::Writable for SLC_TX_FIFO_POP_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_TX_FIFO_POP to value 0"]
impl crate::Resettable for SLC_TX_FIFO_POP_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/slc/slc_tx_fifo_pop.rs <==
#[doc = "Register `SLC_TX_FIFO_POP` reader"]
pub struct R(crate::R<SLC_TX_FIFO_POP_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_TX_FIFO_POP_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_TX_FIFO_POP_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_TX_FIFO_POP_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_TX_FIFO_POP` writer"]
pub struct W(crate::W<SLC_TX_FIFO_POP_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_TX_FIFO_POP_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_TX_FIFO_POP_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_TX_FIFO_POP_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TXFIFO_POP` reader - "]
pub struct SLC_TXFIFO_POP_R(crate::FieldReader<bool, bool>);
impl SLC_TXFIFO_POP_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXFIFO_POP_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXFIFO_POP_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXFIFO_POP` writer - "]
pub struct SLC_TXFIFO_POP_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXFIFO_POP_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
        self.w
    }
}
#[doc = "Field `SLC_TXFIFO_RDATA` reader - "]
pub struct SLC_TXFIFO_RDATA_R(crate::FieldReader<u16, u16>);
impl SLC_TXFIFO_RDATA_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        SLC_TXFIFO_RDATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXFIFO_RDATA_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXFIFO_RDATA` writer - "]
pub struct SLC_TXFIFO_RDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXFIFO_RDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x07ff) | (value as u32 & 0x07ff);
        self.w
    }
}
impl R {
    #[doc = "Bit 16"]
    #[inline(always)]
    pub fn slc_txfifo_pop(&self) -> SLC_TXFIFO_POP_R {
        SLC_TXFIFO_POP_R::new(((self.bits >> 16) & 0x01) != 0)
    }
    #[doc = "Bits 0:10"]
    #[inline(always)]
    pub fn slc_txfifo_rdata(&self) -> SLC_TXFIFO_RDATA_R {
        SLC_TXFIFO_RDATA_R::new((self.bits & 0x07ff) as u16)
    }
}
impl W {
    #[doc = "Bit 16"]
    #[inline(always)]
    pub fn slc_txfifo_pop(&mut self) -> SLC_TXFIFO_POP_W {
        SLC_TXFIFO_POP_W { w: self }
    }
    #[doc = "Bits 0:10"]
    #[inline(always)]
    pub fn slc_txfifo_rdata(&mut self) -> SLC_TXFIFO_RDATA_W {
        SLC_TXFIFO_RDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_TX_FIFO_POP\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_tx_fifo_pop](index.html) module"]
pub struct SLC_TX_FIFO_POP_SPEC;
impl crate::RegisterSpec for SLC_TX_FIFO_POP_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_tx_fifo_pop::R](R) reader structure"]
impl crate::Readable for SLC_TX_FIFO_POP_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_tx_fifo_pop::W](W) writer structure"]
impl crate::Writable for SLC_TX_FIFO_POP_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_TX_FIFO_POP to value 0"]
impl crate::Resettable for SLC_TX_FIFO_POP_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
